@@ -29,6 +29,8 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+/* eslint-disable indent */
+
 function defineCommonExtensionSymbols(apiPrivate)
 {
     if (!apiPrivate.audits)
@@ -48,6 +50,7 @@ function defineCommonExtensionSymbols(apiPrivate)
         PreviousSearchResult: "previousSearchResult"
     };
 
+    /** @enum {string} */
     apiPrivate.Events = {
         AuditStarted: "audit-started-",
         ButtonClicked: "button-clicked-",
@@ -61,6 +64,7 @@ function defineCommonExtensionSymbols(apiPrivate)
         ViewHidden: "view-hidden-"
     };
 
+    /** @enum {string} */
     apiPrivate.Commands = {
         AddAuditCategory: "addAuditCategory",
         AddAuditResult: "addAuditResult",
@@ -68,7 +72,7 @@ function defineCommonExtensionSymbols(apiPrivate)
         ApplyStyleSheet: "applyStyleSheet",
         CreatePanel: "createPanel",
         CreateSidebarPane: "createSidebarPane",
-        CreateStatusBarButton: "createStatusBarButton",
+        CreateToolbarButton: "createToolbarButton",
         EvaluateOnInspectedPage: "evaluateOnInspectedPage",
         ForwardKeyboardEvent: "_forwardKeyboardEvent",
         GetHAR: "getHAR",
@@ -449,7 +453,7 @@ ExtensionPanelImpl.prototype = {
     {
         var id = "button-" + extensionServer.nextObjectId();
         var request = {
-            command: commands.CreateStatusBarButton,
+            command: commands.CreateToolbarButton,
             panel: this._id,
             id: id,
             icon: iconPath,
@@ -803,9 +807,8 @@ var forwardTimer = null;
 
 function forwardKeyboardEvent(event)
 {
-    const Esc = "U+001B";
     // We only care about global hotkeys, not about random text
-    if (!event.ctrlKey && !event.altKey && !event.metaKey && !/^F\d+$/.test(event.keyIdentifier) && event.keyIdentifier !== Esc)
+    if (!event.ctrlKey && !event.altKey && !event.metaKey && !/^F\d+$/.test(event.key) && event.key !== "Escape")
         return;
     var requestPayload = {
         eventType: event.type,
@@ -813,6 +816,8 @@ function forwardKeyboardEvent(event)
         altKey: event.altKey,
         metaKey: event.metaKey,
         keyIdentifier: event.keyIdentifier,
+        key: event.key,
+        code: event.code,
         location: event.location,
         keyCode: event.keyCode
     };
@@ -852,7 +857,7 @@ function ExtensionServerClient()
     this._port.addEventListener("message", this._onMessage.bind(this), false);
     this._port.start();
 
-    window.parent.postMessage("registerExtension", [ channel.port2 ], "*");
+    window.parent.postMessage("registerExtension", "*", [ channel.port2 ]);
 }
 
 ExtensionServerClient.prototype = {
@@ -954,7 +959,7 @@ function platformExtensionAPI(coreAPI)
     {
         return tabId;
     }
-    chrome = window.chrome || {};
+    var chrome = window.chrome || {};
     // Override chrome.devtools as a workaround for a error-throwing getter being exposed
     // in extension pages loaded into a non-extension process (only happens for remote client
     // extensions)
@@ -967,6 +972,7 @@ function platformExtensionAPI(coreAPI)
     chrome.devtools.inspectedWindow.__proto__ = coreAPI.inspectedWindow;
     chrome.devtools.network = coreAPI.network;
     chrome.devtools.panels = coreAPI.panels;
+    chrome.devtools.panels.themeName = themeName;
 
     // default to expose experimental APIs for now.
     if (extensionInfo.exposeExperimentalAPIs !== false) {
@@ -987,27 +993,30 @@ function platformExtensionAPI(coreAPI)
 /**
  * @param {!ExtensionDescriptor} extensionInfo
  * @param {string} inspectedTabId
+ * @param {string} themeName
  * @return {string}
  */
-function buildPlatformExtensionAPI(extensionInfo, inspectedTabId)
+function buildPlatformExtensionAPI(extensionInfo, inspectedTabId, themeName)
 {
     return "var extensionInfo = " + JSON.stringify(extensionInfo) + ";" +
        "var tabId = " + inspectedTabId + ";" +
+       "var themeName = '" + themeName + "';" +
        platformExtensionAPI.toString();
 }
 
 /**
  * @param {!ExtensionDescriptor} extensionInfo
  * @param {string} inspectedTabId
+ * @param {string} themeName
  * @return {string}
  */
-function buildExtensionAPIInjectedScript(extensionInfo, inspectedTabId)
+function buildExtensionAPIInjectedScript(extensionInfo, inspectedTabId, themeName)
 {
     return "(function(injectedScriptId){ " +
         "var extensionServer;" +
         defineCommonExtensionSymbols.toString() + ";" +
         injectedExtensionAPI.toString() + ";" +
-        buildPlatformExtensionAPI(extensionInfo, inspectedTabId) + ";" +
+        buildPlatformExtensionAPI(extensionInfo, inspectedTabId, themeName) + ";" +
         "platformExtensionAPI(injectedExtensionAPI(injectedScriptId));" +
         "return {};" +
         "})";
